@@ -125,6 +125,7 @@ keyword!(
     FALSE,
     FETCH,
     FILTER,
+    FIRST,
     FIRST_VALUE,
     FLOAT,
     FLOOR,
@@ -165,6 +166,7 @@ keyword!(
     LAG,
     LANGUAGE,
     LARGE,
+    LAST,
     LAST_VALUE,
     LATERAL,
     LEAD,
@@ -203,6 +205,7 @@ keyword!(
     NTH_VALUE,
     NTILE,
     NULL,
+    NULLS,
     NULLIF,
     NUMERIC,
     OBJECT,
